import Taro, { Component } from '@tarojs/taro'
import { View, Button, Image } from '@tarojs/components'
import './index.scss'


export default class ImagePicker extends Component {
  static defaultProps = {
    time: Date.parse(new Date()),
    urls: HOST,
  }

  async componentWillReceiveProps(nextProps) {
    const token = await this.getStorage('token')
    const urls = this.props.urls
    this.setState({
      token,
      imageUrls: !urls ? [] : [urls]
    })
  }

  getStorage(key) {
    return Taro.getStorage({ key }).then(res => res.data).catch(() => '')
  }

  async handleUpload() {
    const { api, num = 1, id, onChange, keyId } = this.props
    const token = await this.getStorage('token')
    Taro.chooseImage({
      count: num, // 最多选择多少张图片
      sizeType: ['compressed'], // 压缩图像文件
      sourceType: ['album', 'camera'], // 从相册和相机选择图片
      success: (res) => {
        const files = res.tempFilePaths;
        const condition = res.tempFiles;
        for (var i = 0; i < condition.length; i++) {
          const isJpgOrPng = condition[i].type === 'image/jpeg' || condition[i].type === 'image/png';
          if (!isJpgOrPng) {
            Taro.showToast({
              title: '仅支持JPG和PNG格式的图片',
              icon: 'none',
              mask: true
            })
          }
          const isLt2M = condition[i].size / 1024 / 1024 < 2;
          if (!isLt2M) {
            Taro.showToast({
              title: '仅支持小于2MB的图片',
              icon: 'none',
              mask: true
            })
          }
          if (!isJpgOrPng || !isLt2M) {
            return false;
          }
        }
        // 上传每张图片到服务器
        files.forEach((file) => {
          const formData = {}
          formData[keyId] = id
          Taro.uploadFile({
            url: HOST + api,// 上传接口地址
            // url: 'http://zhcq.jishutao.com/gw/user/logo', 
            filePath: file,
            header: {
              'Authorization': token,
            },
            formData,
            name: 'file', // 服务端接收的文件字段名
            success: (result) => {
              if (result.statusCode === 200) {
                const responseData = JSON.parse(result.data); // 服务器返回的数据
                onChange(responseData.data) // 调用父级方法存储
                // 可以根据服务器返回的数据做一些逻辑处理
                const { imageUrls } = this.state;
                this.setState({ imageUrls: [responseData.data] })
                // this.setState({ imageUrls: [...imageUrls, ...[responseData.data]] });
              } else {
                // 处理上传失败的情况
                Taro.showToast({
                  title: '上传失败',
                  icon: 'none',
                  mask: true
                })
              }
            },
            fail: (error) => {
              // 处理上传失败的情况
              // Taro.showToast({
              //   title: '上传失败',
              //   icon: 'none',
              //   mask: true
              // })
            },
          });
        });
      },
    });
  }

  // 图片删除
  async deleteImg(options) {
    const { url, payload, method } = options
    const token = await this.getStorage('token')
    Taro.request({
      url,
      method,
      data: payload,
      header: {
        'content-type': "application/json",
        'Authorization': token,
        'Accept': 'application/json, text/javascript,'
      },
      dataType: 'json',
    }).then((res) => {

    }).catch((err) => {

    })
  }

  handleDelete(index) {
    const { imageUrls } = this.state;
    const updatedUrls = [...imageUrls];
    let obj = {
      url: HOST + this.props.api + `/${this.props.id}`,
      method: 'DELETE',
      payload: {},
    }
    this.deleteImg(obj)
    updatedUrls.splice(index, 1);
    this.setState({ imageUrls: updatedUrls });

  }

  handlePreview(index) {
    const { api, id, time } = this.props
    const { imageUrls, token } = this.state;
    const urls = imageUrls.map((url) => HOST + api + `/${id}?token=${token}&t=${time}`);
    Taro.previewImage({
      current: urls[index],
      urls,
    });
  }

  render() {
    const { imageUrls = [], token } = this.state
    const { api, time, id, num = 1 } = this.props
    return (
      <View className='upload'>
        {imageUrls && imageUrls.map((url, index) => (
          <View className='upload-item' key={index}>
            <Image
              className='upload-item-img'
              src={HOST + api + `/${id}?token=${token}&t=${time}`}
              mode='aspectFit'
            // onClick={() => this.handlePreview(index)}
            />
            <View className='upload-item-delete'
              onClick={this.handleDelete.bind(this, index)}
            >
              删除
            </View>
          </View>
        ))}
        {imageUrls.length < num && <View className='upload-add' onClick={this.handleUpload.bind(this)}>+</View>}
      </View>
    )
  }
}

