import Taro, { Component } from '@tarojs/taro'
import { View, Input, Picker, Label, Button } from '@tarojs/components'
import { Loading } from '@components'
import { connect } from '@tarojs/redux'
import * as actions from '@actions/template'
import * as report from '@actions/report'
import ImagePicker from '../../components/imagePicker'
import './templatedetail.scss'

@connect(state => state.home, { ...actions, ...report })
class TemplateDetail extends Component {

  config = {
    navigationBarTitleText: '报告模板编辑'
  }

  state = {
    loading: true,
    selector: [
      { name: "文本项", type: "text" },
      { name: "日期项", type: "date" },
      { name: "起止时间", type: "dateRange" },
    ],
    visible: "",
    data: {
      tags: [],
    },
    metadata: [],
    chapterType: [
      { title: "立项背景与意义", key: "BACKGROUND", keywords: ['必要性'] },
      { title: "国内外研究现状与发展趋势", key: "RESEARCH_STATUS", keywords: ['研究现状', '发展趋势'] },
      { title: "项目主要研究内容", key: "RESEARCH", keywords: ['技术特点', '技术研究', '实际应用'] },
      { title: "关键技术与创新点", key: "INNOVATION", keywords: ['关键技术', '创新点'] },
      { title: "拟解决的关键问题", key: "SOLVE_PROBLEM", keywords: ['解决的问题', '解决的关键问题'] },
      { title: "实施方案及进度安排", key: "SOLUTION", keywords: ['实施方案'] },
      { title: "经费预算", key: "BUDGET", keywords: [] },
      { title: "经济及社会效益分析", key: "BENEFIT_ANALYSIS", keywords: ['经济效益', '社会效益', '经济效益分析', '社会效益分析'] },
      { title: "项目风险分析和对策", key: "RISK", keywords: ['风险分析', '风险对策'] },
      { title: "自定义章节", key: "USER_DEFINED", keywords: [] },
    ],
    chapters: [],
    aeList: [],
    name: "",
    newvb: false,
    popup: false,
  }

  componentDidMount() {
    this.getData()
    this.getQuery()
  }

  // 详情
  getData() {
    this.setState({ loading: true })
    let payload = {
      id: this.$router.params.id,
    }
    this.props.reportTemplate(payload).then((data) => {
      let datas = data
      datas.tags = !data.tags ? [] : data.tags
      this.setState({
        loading: false,
        data: datas,
        metadata: data.metadata || [],
        chapters: data.chapters || [],
      }, () => {
        !!data.companyId && this.getCompany(data.companyId)
      })
    }).catch(() => {
      // setInterval(function () {
      //   Taro.navigateBack()
      // }, 800)
      this.setState({ loading: false })
    })
  }

  // 获取企业列表
  getQuery() {
    let payload = {
      name: "",
      size: 99,
    }
    this.props.query(payload).then((data) => {
      this.setState({
        aeList: data,
      })
    }).catch(() => {

    })
  }
  // 获取企业名
  getCompany(id) {
    const obj = this.state.data
    let payload = {
      id,
    }
    this.props.selcompany(payload).then((data) => {
      obj.companyName = data.name
      this.setState({
        data: obj,
      })
    }).catch(() => {

    })
  }
  // 添加新项
  onChange = e => {
    this.setState({
      type: this.state.selector[e.detail.value].type,
      inputName: e.detail.value == 2 ? "起止时间" : undefined,
      visible: "add"
    })
  }
  // 阿拉伯数字转中文
  numberToChinese(num) {
    var arr1 = new Array('零', '一', '二', '三', '四', '五', '六', '七', '八', '九');
    var arr2 = new Array('', '十', '百', '千', '万', '十', '百', '千', '亿', '十', '百', '千', '万', '十', '百', '千', '亿');//可继续追加更高位转换值
    if (!num || isNaN(num)) {
      return "零";
    }
    var english = num.toString().split("");
    var result = "";
    for (var i = 0; i < english.length; i++) {
      var des_i = english.length - 1 - i;//倒序排列设值
      result = arr2[i] + result;
      var arr1_index = english[des_i];
      result = arr1[arr1_index] + result;
    }
    //将【零千、零百】换成【零】 【十零】换成【十】
    result = result.replace(/零(千|百|十)/g, '零').replace(/十零/g, '十');
    //合并中间多个零为一个零
    result = result.replace(/零+/g, '零');
    //将【零亿】换成【亿】【零万】换成【万】
    result = result.replace(/零亿/g, '亿').replace(/零万/g, '万');
    //将【亿万】换成【亿】
    result = result.replace(/亿万/g, '亿');
    //移除末尾的零
    result = result.replace(/零+$/, '');
    //将【零一十】换成【零十】
    //result = result.replace(/零一十/g, '零十');//貌似正规读法是零一十
    //将【一十】换成【十】
    result = result.replace(/^一十/g, '十');
    return result;
  }
  // 字符串拼接
  getTitleWithChineseNum(index, title) {
    return this.numberToChinese(index + 1) + '、' + title
  }
  // 章节添加
  onChapterChange = e => {
    let list = this.state.chapters
    let obj = this.state.chapterType[e.detail.value]
    let data = {
      chapterType: obj.key,
      content: "",
      fullTitle: this.getTitleWithChineseNum(list.length, obj.title),
      keywords: obj.keywords,
      title: obj.title,
    }
    list.push(data)
    this.setState({
      chapters: list
    })
  }
  // 选中关联企业
  onAeChange = e => {
    const { aeList } = this.state
    let obj = aeList[e.detail.value]
    let list = this.state.data
    list.companyName = obj.name
    list.companyId = obj.id
    this.setState({
      data: list,
    })
  }
  // 企业添加
  onAeCancel = () => {
    this.setState({
      name: "",
      newvb: false,
    })
  }
  // 企业添加
  onAeOk = () => {
    if (!this.state.name) {
      Taro.showToast({
        title: "请输入新企业名称",
        icon: 'none'
      })
      return
    }
    const payload = {
      name: this.state.name,
    }
    this.props.company(payload).then((data) => {
      let obj = this.state.data
      obj.companyName = data.name
      obj.companyId = data.id
      this.setState({
        data: obj,
        newvb: false,
      })
    }).catch(() => {

    })

  }
  // 添加新项弹窗
  onCancel = () => {
    this.setState({
      inputName: undefined,
      inputText: undefined,
      dateSel: undefined,
      dataStart: undefined,
      dataEnd: undefined,
      indx: undefined,
      type: "",
      visible: "",
    })
  }
  // 添加新项弹窗
  onOk = () => {
    const { visible, metadata, inputName, inputText, type, indx, dateSel, dataStart, dataEnd } = this.state
    // if (visible == "add") {
    let list = []
    if (!inputName) {
      Taro.showToast({
        title: "请输入字段名称",
        icon: 'none'
      })
      return
    }
    if (type == "text") {
      if (!inputText) {
        Taro.showToast({
          title: "请输入字段值",
          icon: 'none'
        })
        return
      }
      list.push({ name: inputName, value: inputText, type: type })
    } else if (type == "date") {
      if (!dateSel) {
        Taro.showToast({
          title: "请选择日期",
          icon: 'none'
        })
        return
      }
      list.push({ name: inputName, value: dateSel, type: type })
    } else if (type == "dateRange") {
      if (!dataStart) {
        Taro.showToast({
          title: "请选择开始日期",
          icon: 'none'
        })
        return
      }
      if (!dataEnd) {
        Taro.showToast({
          title: "请选择结束日期",
          icon: 'none'
        })
        return
      }
      list.push({ name: inputName, value: dataStart + " " + dataEnd, type: type })
    }

    if (visible == "edit") {
      let nlist = metadata
      nlist[indx] = list[0]
      this.setState({
        metadata: nlist,
        visible: "",
      })
    } else {
      this.setState({
        metadata: [...metadata, ...list],
        visible: "",
      })
    }
  }
  // 修改章节名
  onChapTitle = (i, e) => {
    const data = this.state.chapters
    data.forEach(function (item, index) {
      if (index == i) {
        item.title = e.detail.value
      }
    })
    this.setState({
      chapters: data
    })
  }
  // 修改章节关键词
  onChapKeywords = (i, e) => {
    const data = this.state.chapters
    data.forEach(function (item, index) {
      if (index == i) {
        let val = e.detail.value.replace(/[\uff0c]/g, ",")
        item.keywords = !val ? [] : val.split(",")
      }
    })
    this.setState({
      chapters: data
    })
  }
  // 二级确认
  toggleVisible = () => {
    this.setState({
      popup: !this.state.popup,
    })
  }
  // 删除章节
  delChap = () => {
    const list = this.state.chapters
    list.splice(this.state.delIndex, 1)
    for (var i = 0; i < list.length; i++) {
      list[i].fullTitle = this.getTitleWithChineseNum(i, list[i].title)
    }
    this.setState({
      chapters: list
    })
    this.toggleVisible()
  }
  // 保存
  onSubsmit = () => {
    const { data, metadata, chapters } = this.state
    if (!data.name) {
      Taro.showToast({
        title: "请填写报告模板名称！",
        icon: 'none'
      })
      return
    }
    data.metadata = metadata
    data.chapters = chapters
    let payload = data
    this.props.updateTemplate(payload).then((data) => {
      Taro.showToast({
        title: "保存成功",
        icon: 'none'
      })
      setTimeout(function () {
        Taro.navigateBack()
      }, 400)
    }).catch(() => {

    })
  }


  render() {
    // if (this.state.loading) {
    //   return <Loading />
    // }
    const { data, visible, metadata, type, chapterType, chapters, aeList } = this.state
    return (
      <View className='home main'>
        <View className='home-item'>
          <View className='home-item-tit'>报告模板名称</View>
          <Input
            value={data.name}
            className='home-item-val'
            placeholder='请输入项目名称'
            onChange={e => {
              let obj = data
              obj.name = e.detail.value
              this.setState({
                data: obj,
              })
            }}
          />
        </View>
        <View className='home-item'>
          <View className='home-item-tit'>报告模板标签</View>
          <Input
            value={data.tags.toString().replace(/,/g, "，")}
            className='home-item-val'
            placeholder='模板标签，输入逗号分割'
            onChange={e => {
              let obj = data
              let val = e.detail.value.replace(/[\uff0c]/g, ",")
              obj.tags = !val ? [] : val.split(",")
              this.setState({
                data: obj,
              })
            }}
          />
        </View>
        <View className='home-item'>
          <View className='home-item-tit'>关联企业</View>
          <View className='home-item-vals'>
            <Picker mode='selector' range={aeList} rangeKey="name"
              onChange={this.onAeChange}
            >
              <View className='home-item-vals-txt'>{data.companyName || "请选择关联企业"}</View>
            </Picker>
            <View className='home-item-vals-bt'>
              <Button size='mini' type='primary' onClick={() => { this.setState({ newvb: true }) }}>+新增企业</Button>
            </View>
          </View>
        </View>
        <View className='home-item'>
          <View className='home-item-tit'>企业LOGO</View>
          <ImagePicker
            id={data.id}
            keyId="templateId"
            api='/gw/user/reportTemplate/logo'
            urls={data.logoPath}
            onChange={(path) => {
              let obj = data
              obj.logoPath = path
              this.setState({
                data: obj,
              })
            }}
          />
        </View>
        <View className='home-item'>
          <View className='home-item-tit'>项目名称</View>
          <Input
            value={data.reportName}
            className='home-item-val'
            placeholder='请输入项目名称'
            onChange={e => {
              let obj = data
              obj.reportName = e.detail.value
              this.setState({
                data: obj,
              })
            }}
          />
        </View>
        {
          metadata.map((item, index) =>
            <View className='home-item' key={index}
              onClick={() => {
                this.setState({
                  indx: index,
                  type: item.type,
                  inputName: item.name,
                  visible: "edit",
                  inputText: item.type == "text" ? item.value : undefined,
                  dateSel: item.type == "date" ? item.value : undefined,
                  dataStart: item.type == "dateRange" ? item.value.split(" ")[0] : undefined,
                  dataEnd: item.type == "dateRange" ? item.value.split(" ")[1] : undefined,
                })
              }}
            >
              <View className='home-item-tits'>
                <View className='home-item-tits-txt'>{item.name}</View>
                <View className='home-item-tits-bt'>
                  <Button size='mini' type='warn'
                    onClick={e => {
                      e.stopPropagation()
                      let list = this.state.metadata
                      list.splice(index, 1)
                      this.setState({
                        metadata: list
                      })
                    }}
                  >删除</Button>
                </View>
              </View>
              {item.type == "text" && <View className='home-item-val'>{item.value}</View>}
              {item.type == "date" && <View className='home-item-val'>{item.value}</View>}
              {item.type == "dateRange" && <View className='home-item-val'>{item.value.replace(" ", " → ")}</View>}
            </View>
          )
        }
        <View className='home-item'>
          <Picker mode='selector' range={this.state.selector} rangeKey="name"
            onChange={this.onChange}
          >
            <Button>+添加新项</Button>
          </Picker>
        </View>
        <View className='home-line' />
        {
          chapters.map((item, index) =>
            <View className='home-item' key={index} style={{ marginBottom: 10, }}>
              <View className='home-item-tits'>
                <Input
                  value={item.title}
                  className='home-item-tits-txt'
                  style={{ borderBottom: "1px solid #d9d9d9" }}
                  onChange={(e) => {
                    this.onChapTitle(index, e)
                  }}
                />
                <View className='home-item-tits-bt'>
                  <Button size='mini' type='warn'
                    onClick={e => {
                      e.stopPropagation()
                      this.setState({
                        delIndex: index
                      })
                      this.toggleVisible()
                    }}
                  >删除</Button>
                </View>
              </View>
              <View className='home-item-text'>
                <View>章节关键词：</View>
                <Input
                  value={item.keywords.toString().replace(/,/g, "，")}
                  className='home-item-text-val'
                  placeholder='输入逗号分割'
                  onChange={(e) => {
                    this.onChapKeywords(index, e)
                  }}
                />
              </View>
            </View>
          )
        }

        <View className='home-item'>
          <Picker mode='selector' range={chapterType} rangeKey="title"
            onChange={this.onChapterChange}
          >
            <Button>+添加章节</Button>
          </Picker>
        </View>
        <View className='home-item' style={{ marginTop: 60, paddingBottom: 30 }}>
          <Button type='primary' onClick={this.onSubsmit}>保存</Button>
        </View>
        {/* 新增项 */}
        {visible != "" &&
          <View className='mask'>
            <View className='count'>
              <View className='count_top'>
                <Input
                  value={this.state.inputName}
                  className='count_top_input'
                  placeholder='字段名称'
                  onChange={e => { this.setState({ inputName: e.detail.value }) }}
                />
                {type == "text" &&
                  <Input
                    value={this.state.inputText}
                    style={{ marginTop: 15 }}
                    className='count_top_input'
                    placeholder='请输入字段值'
                    onChange={e => { this.setState({ inputText: e.detail.value }) }}
                  />}
                {type == "date" &&
                  <Picker mode='date' value={this.state.dateSel}
                    onChange={e => {
                      this.setState({
                        dateSel: e.detail.value,
                      })
                    }}>
                    <View className={!this.state.dateSel ? 'count_top_dates' : 'count_top_date'}>
                      {!this.state.dateSel ? "请选择日期" : this.state.dateSel}
                    </View>
                  </Picker>
                }
                {type == "dateRange" &&
                  <Picker mode='date' value={this.state.dataStart}
                    onChange={e => {
                      this.setState({
                        dataStart: e.detail.value,
                      })
                    }}>
                    <View className={!this.state.dataStart ? 'count_top_dates' : 'count_top_date'}>
                      {!this.state.dataStart ? "开始日期" : this.state.dataStart}
                    </View>
                  </Picker>
                }
                {type == "dateRange" &&
                  <Picker mode='date' value={this.state.dataEnd}
                    onChange={e => {
                      this.setState({
                        dataEnd: e.detail.value,
                      })
                    }}>
                    <View className={!this.state.dataEnd ? 'count_top_dates' : 'count_top_date'}>
                      {!this.state.dataEnd ? "结束日期" : this.state.dataEnd}
                    </View>
                  </Picker>
                }
              </View>
              <View className='count_foot'>
                <Button onClick={this.onCancel}>取消</Button>
                <Button style={{ marginTop: 0 }}
                  onClick={this.onOk}
                >确认</Button>
              </View>
            </View>
          </View>}
        {/* 新增企业 */}
        {this.state.newvb &&
          <View className='mask'>
            <View className='count'>
              <View className='title'>新增企业名称</View>
              <View className='count_top'>
                <Input
                  value={this.state.name}
                  className='count_top_input'
                  placeholder='请输入新企业名称'
                  onChange={e => { this.setState({ name: e.detail.value }) }}
                />
              </View>
              <View className='count_foot'>
                <Button onClick={this.onAeCancel}>取消</Button>
                <Button style={{ marginTop: 0 }}
                  onClick={this.onAeOk}
                >确认</Button>
              </View>
            </View>
          </View>}
        {/* 二级确认 */}
        {this.state.popup &&
          <View className='mask'>
            <View className='count'>
              <View className='title' style={{ margin: "60px 0" }}>确认删除吗？</View>
              <View className='count_foot'>
                <Button onClick={this.toggleVisible}>取消</Button>
                <Button style={{ marginTop: 0 }}
                  onClick={this.delChap}
                >确认</Button>
              </View>
            </View>
          </View>}
      </View>
    )
  }
}

export default TemplateDetail